window.Gleam.initSearch([{"doc":"clad","title":"clad","content":"# clad\n\n\n[![Package Version](https://img.shields.io/hexpm/v/clad)](https://hex.pm/packages/clad)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/clad/)\n\n\nCommand line argument decoders for Gleam.\n\n- Clad provides primitives to build a `dynamic.Decoder` for command line arguments.\n- Arguments can be specified with long names (`--name`) or short names (`-n`).\n- Values are decoded in the form `--name value` or `--name=value`.\n- Boolean flags do not an explicit value. If the flag exists it is `True`, and if it is missing it is `False`. (i.e. `--verbose`)\n\n\n## Usage\n\n```sh\ngleam add clad\n```\n\nThis program is in the [examples directory](https://github.com/ryanmiville/clad/tree/main/test/examples)\n\n```gleam\nimport argv\nimport clad\nimport gleam/dynamic\nimport gleam/io\nimport gleam/list\nimport gleam/string\n\ntype Args {\n  Args(name: String, count: Int, scream: Bool)\n}\n\nfn greet(args: Args) {\n  let greeting = case args.scream {\n    True -&gt; &quot;HEY &quot; &lt;&gt; string.uppercase(args.name) &lt;&gt; &quot;!&quot;\n    False -&gt; &quot;Hello, &quot; &lt;&gt; args.name &lt;&gt; &quot;.&quot;\n  }\n  list.repeat(greeting, args.count) |&gt; list.each(io.println)\n}\n\npub fn main() {\n  let args =\n    dynamic.decode3(\n      Args,\n      clad.string(long_name: &quot;name&quot;, short_name: &quot;n&quot;),\n      clad.int(long_name: &quot;count&quot;, short_name: &quot;c&quot;) |&gt; clad.with_default(1),\n      clad.bool(long_name: &quot;scream&quot;, short_name: &quot;s&quot;),\n    )\n    |&gt; clad.decode(argv.load().arguments)\n\n  case args {\n    Ok(args) -&gt; greet(args)\n    _ -&gt;\n      io.println(\n        &quot;\nOptions:\n  -n, --name &lt;NAME&gt;    Name of the person to greet\n  -c, --count &lt;COUNT&gt;  Number of times to greet [default: 1]\n  -s, --scream         Whether or not to scream greeting\n      &quot;,\n      )\n  }\n}\n```\n\nRun the program\n\n```sh\n❯ gleam run -m examples/greet -- -n Joe\nHello, Joe.\n❯ gleam run -m examples/greet -- --name=Joe\nHello, Joe.\n❯ gleam run -m examples/greet -- --name Joe --count 3 --scream\nHEY JOE!\nHEY JOE!\nHEY JOE!\n❯ gleam run -m examples/greet\n\nOptions:\n  -n, --name &lt;NAME&gt;    Name of the person to greet\n  -c, --count &lt;COUNT&gt;  Number of times to greet [default: 1]\n  -s, --scream         Whether or not to scream greeting\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/clad&gt;.\n","url":"index.html"},{"doc":"clad","title":"bool","content":"pub fn bool(\n  long_name long_name: String,\n  short_name short_name: String,\n) -&gt; fn(Dynamic) -&gt; Result(Bool, List(DecodeError))\n A decoder that decodes Bool arguments.\n # Examples\n \n clad.bool(long_name: &quot;verbose&quot;, short_name: &quot;v&quot;)\n |&gt; clad.decode([&quot;-v&quot;])\n // -&gt; Ok(True)\n \n \n clad.bool(long_name: &quot;verbose&quot;, short_name: &quot;v&quot;)\n |&gt; clad.decode([])\n // -&gt; Ok(False)\n \nSynonyms:\nclad.bool\nclad bool","url":"clad.html#bool"},{"doc":"clad","title":"decode","content":"pub fn decode(\n  decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  arguments: List(String),\n) -&gt; Result(a, List(DecodeError))\n Run a decoder on a list of command line arguments, decoding the value if it\n is of the desired type, or returning errors.\n\n This function works well with the argv package.\n\n # Examples\n \n dynamic.decode2(\n   SignUp,\n   clad.string(long_name: &quot;name&quot;, short_name: &quot;n&quot;),\n   clad.string(long_name: &quot;email&quot;, short_name: &quot;e&quot;),\n )\n |&gt; clad.decode([&quot;-n&quot;, &quot;Lucy&quot;, &quot;--email=lucy@example.com&quot;])\n // -&gt; Ok(SignUp(name: &quot;Lucy&quot;, email: &quot;lucy@example.com&quot;))\n \n with argv:\n \n dynamic.decode2(\n   SignUp,\n   clad.string(long_name: &quot;name&quot;, short_name: &quot;n&quot;),\n   clad.string(long_name: &quot;email&quot;, short_name: &quot;e&quot;),\n )\n |&gt; clad.decode(argv.load().arguments)\n \nSynonyms:\nclad.decode\nclad decode","url":"clad.html#decode"},{"doc":"clad","title":"float","content":"pub fn float(\n  long_name long_name: String,\n  short_name short_name: String,\n) -&gt; fn(Dynamic) -&gt; Result(Float, List(DecodeError))\n A decoder that decodes Float arguments.\n # Examples\n \n clad.float(long_name: &quot;price&quot;, short_name: &quot;p&quot;)\n |&gt; clad.decode([&quot;--price&quot;, &quot;2.50&quot;])\n // -&gt; Ok(2.5)\n \nSynonyms:\nclad.float\nclad float","url":"clad.html#float"},{"doc":"clad","title":"int","content":"pub fn int(\n  long_name long_name: String,\n  short_name short_name: String,\n) -&gt; fn(Dynamic) -&gt; Result(Int, List(DecodeError))\n A decoder that decodes Int arguments.\n # Examples\n \n clad.int(long_name: &quot;count&quot;, short_name: &quot;c&quot;)\n |&gt; clad.decode([&quot;-c&quot;, &quot;2&quot;])\n // -&gt; Ok(2)\n \nSynonyms:\nclad.int\nclad int","url":"clad.html#int"},{"doc":"clad","title":"string","content":"pub fn string(\n  long_name long_name: String,\n  short_name short_name: String,\n) -&gt; fn(Dynamic) -&gt; Result(String, List(DecodeError))\n A decoder that decodes String arguments.\n # Examples\n \n clad.string(long_name: &quot;name&quot;, short_name: &quot;n&quot;)\n |&gt; clad.decode([&quot;-n&quot;, &quot;Lucy&quot;])\n // -&gt; Ok(&quot;Lucy&quot;)\n \nSynonyms:\nclad.string\nclad string","url":"clad.html#string"},{"doc":"clad","title":"with_default","content":"pub fn with_default(\n  decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  default: a,\n) -&gt; fn(Dynamic) -&gt; Result(a, List(DecodeError))\n Provide a default value for a decoder.\n # Examples\n \n clad.int(long_name: &quot;count&quot;, short_name: &quot;c&quot;) |&gt; clad.with_default(1)\n |&gt; clad.decode([])\n // -&gt; Ok(1)\n \n \n clad.int(long_name: &quot;count&quot;, short_name: &quot;c&quot;) |&gt; clad.with_default(1)\n |&gt; clad.decode([&quot;-c&quot;, &quot;2&quot;])\n // -&gt; Ok(2)\n \nSynonyms:\nclad.with_default\nclad with_default","url":"clad.html#with_default"},{"doc":"clad","title":"clad","content":"","url":"clad.html"}]);